import sys
import codecs
import snowballstemmer

def usage():
    print('''usage: %s [-l <language>] [-i <input file>] [-o <output file>] [-c <character encoding>] [-p[2]] [-h]

The input file consists of a list of words to be stemmed, one per
line. Words should be in lower case, but (for English) A-Z letters
are mapped to their a-z equivalents anyway. If omitted, stdin is
used.

If -c is given, the argument is the character encoding of the input
and output files.  If it is omitted, the UTF-8 encoding is used.

If -p is given the output file consists of each word of the input
file followed by \"->\" followed by its stemmed equivalent.
If -p2 is given the output file is a two column layout containing
the input words in the first column and the stemmed equivalents in
the second column.

Otherwise, the output file consists of the stemmed words, one per
line.

-h displays this help''' % sys.argv[0])

def main():
    argv = sys.argv[1:]
    if len(argv) < 5:
        usage()
    else:
        pretty = 0
        input = ''
        output = ''
        encoding = 'utf_8'
        language = 'English'
        show_help = False
        while len(argv):
            arg = argv.pop(0)
            if arg == '-h':
                show_help = True
                break
            elif arg == "-p":
                pretty = 1
            elif arg == "-p2":
                pretty = 2
            elif arg == "-l":
                if len(argv) == 0:
                    show_help = True
                    break
                language = argv.pop(0)
            elif arg == "-i":
                if len(argv) == 0:
                    show_help = True
                    break
                input = argv.pop(0)
            elif arg == "-o":
                if len(argv) == 0:
                    show_help = True
                    break
                output = argv.pop(0)
            elif arg == "-c":
                if len(argv) == 0:
                    show_help = True
                    break
                encoding = argv.pop(0)
        if show_help or input == '' or output == '':
            usage()
        else:
            stemming(language, input, output, encoding, pretty)


def stemming(lang, input, output, encoding, pretty):
    stemmer = snowballstemmer.stemmer(lang)
    with codecs.open(input, "r", encoding) as infile:
        with codecs.open(output, "w", encoding) as outfile:
            for original in infile.readlines():
                original = original.strip()
                # Convert only ASCII-letters to lowercase, to match C behavior
                original = ''.join((c.lower() if 'A' <= c <= 'Z' else c for c in original))
                stemmed = stemmer.stemWord(original)
                if pretty == 0:
                    if stemmed != "":
                        outfile.write(stemmed)
                elif pretty == 1:
                    outfile.write(original, " -> ", stemmed)
                elif pretty == 2:
                    outfile.write(original)
                    if len(original) < 30:
                        outfile.write(" " * (30 - len(original)))
                    else:
                        outfile.write("\n")
                        outfile.write(" " * 30)
                    outfile.write(stemmed)
                outfile.write('\n')

main()



import sys
import re
import snowballstemmer


def usage():
    print("testapp.py <algorithm> \"sentence\"...")

def main():
    argv = sys.argv
    if len(argv) < 1:
        usage()
        return
    algorithm = 'english'
    if len(argv) > 2:
        algorithm = argv[1]
        argv = argv[2:]
    else:
        argv = argv[1:]
    stemmer = snowballstemmer.stemmer(algorithm)
    splitter = re.compile(r"[\s\.-]")
    for arg in argv:
        for word in splitter.split(arg):
            if word == '':
                continue
            original = word.lower()
            print(original + " -> " + stemmer.stemWord(original))
main()



#! /bin/sh/env python

import sys
import re
import os

python_out_folder = sys.argv[1]

filematch = re.compile(r"(\w+)_stemmer\.py$")

imports = []
languages = []

for pyscript in os.listdir(python_out_folder):
    match = filematch.match(pyscript)
    if (match):
        langname = match.group(1)
        titlecase = re.sub(r"_", "", langname.title())
        languages.append("    '%(lang)s': %(title)sStemmer," % {'lang': langname, 'title': titlecase})
        imports.append('from .%(lang)s_stemmer import %(title)sStemmer' % {'lang': langname, 'title': titlecase})
imports.sort()
languages.sort()

if len(languages) == 0:
    raise AssertionError('languages list is empty!')

src = '''__all__ = ('language', 'stemmer')

%(imports)s

_languages = {
%(languages)s
}

try:
    import Stemmer
    cext_available = True
except ImportError:
    cext_available = False

def algorithms():
    if cext_available:
        return Stemmer.language()
    else:
        return list(_languages.keys())

def stemmer(lang):
    if cext_available:
        return Stemmer.Stemmer(lang)
    if lang.lower() in _languages:
        return _languages[lang.lower()]()
    else:
        raise KeyError("Stemming algorithm '%%s' not found" %% lang)
''' % {'imports': '\n'.join(imports), 'languages': '\n'.join(languages)}

with open(os.path.join(python_out_folder, '__init__.py'), 'w') as out:
    out.write(src)



#!env python
# Simple (but slow) iconv replacement in Python.
import sys

in_cs = out_cs = in_file = out_file = pending = None
for arg in sys.argv[1:]:
    if pending != None:
        arg = pending + arg
        pending = None
    if arg.startswith('-'):
        if arg[1] in ('f', 't', 'o'):
            if len(arg) == 2:
                pending = arg
                continue
        if arg[1] == 'f':
            in_cs = arg[2:]
            continue
        if arg[1] == 't':
            out_cs = arg[2:]
            continue
        if arg[1] == 'o':
            out_file = open(arg[2:], 'wb')
            continue
        print("Unknown option: '%s'" % arg)
        sys.exit(1)
    if in_file == None:
        in_file = open(arg, 'rb')
        continue
    print("Too many arguments")
    sys.exit(1)

if in_cs == None:
    print("Need to specify input cs with -f")
    sys.exit(1)
if out_cs == None:
    print("Need to specify output cs with -t")
    sys.exit(1)

if in_file == None:
    if hasattr(sys.stdin, 'buffer'):
        in_file = sys.stdin.buffer
    else:
        in_file = sys.stdin
if out_file == None:
    if hasattr(sys.stdout, 'buffer'):
        out_file = sys.stdout.buffer
    else:
        out_file = sys.stdout

out_file.write(in_file.read().decode(in_cs).encode(out_cs))
